Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-pages.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJaime Martinez <jmartinez@gitlab.com>2020-09-14 13:24:22 +0300
committerJaime Martinez <jmartinez@gitlab.com>2020-09-15 07:49:29 +0300
commitd4c05e5ec0b9aeeed8693e72cdaa234d1b597df9 (patch)
tree6d69e253ba2d0180c778ec4eb30acc4e8553c3b9 /metrics/metrics.go
parent6fa2497adfcb2a3ce8b119b7caa6a1f0ff4a30f9 (diff)
Apply suggestions from feedback
Update metric name
Diffstat (limited to 'metrics/metrics.go')
-rw-r--r--metrics/metrics.go20
1 files changed, 11 insertions, 9 deletions
diff --git a/metrics/metrics.go b/metrics/metrics.go
index 9923043b..cb4287c8 100644
--- a/metrics/metrics.go
+++ b/metrics/metrics.go
@@ -99,15 +99,17 @@ var (
Help: "The number of VFS operations",
}, []string{"vfs_name", "operation", "success"})
- // ZipFileServingReqTotal is the number of requests made to Object Storage by zip file serving
- ZipFileServingReqTotal = prometheus.NewCounterVec(prometheus.CounterOpts{
- Name: "gitlab_pages_httprange_zip_reader_requests_total",
- Help: "The number of requests made to Object Storage by zip file serving with different status codes",
+ // ObjectStorageBackendReqTotal is the number of requests made to Object Storage by zip file serving
+ // Could be bigger than the number of pages served.
+ ObjectStorageBackendReqTotal = prometheus.NewCounterVec(prometheus.CounterOpts{
+ Name: "gitlab_pages_object_storage_backend_requests_total",
+ Help: "The number of requests made to Object Storage by zip file serving with different status codes." +
+ "Could be bigger than the number of requests served",
}, []string{"status_code"})
- // ZipFileServingReqDuration is the time it takes to get a response from Object Storage in seconds for zip file servings
- ZipFileServingReqDuration = prometheus.NewGaugeVec(prometheus.GaugeOpts{
- Name: "gitlab_pages_httprange_zip_reader_requests_duration",
+ // ObjectStorageBackendReqDuration is the time it takes to get a response from Object Storage in seconds for zip file servings
+ ObjectStorageBackendReqDuration = prometheus.NewGaugeVec(prometheus.GaugeOpts{
+ Name: "gitlab_pages_object_storage_backend_requests_duration",
Help: "The time (in seconds) it takes to get a response from the Object Storage provider for zip file serving",
}, []string{"status_code"})
)
@@ -130,7 +132,7 @@ func MustRegister() {
DiskServingFileSize,
ServingTime,
VFSOperations,
- ZipFileServingReqTotal,
- ZipFileServingReqDuration,
+ ObjectStorageBackendReqTotal,
+ ObjectStorageBackendReqDuration,
)
}